package com.yaohun.crazyprizepool.manager;

import com.yaohun.crazyprizepool.Main;
import com.yaohun.crazyprizepool.data.ContentData;
import com.yaohun.crazyprizepool.data.PoolData;
import me.Demon.DemonPlugin.DemonAPI;
import org.bukkit.configuration.ConfigurationSection;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;

import java.io.File;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

public class PoolManager {

    private Main plugin;
    private Map<UUID, Map<String,Integer>> uuidDataMap = new HashMap<>();
    private Map<String, PoolData> poolDataMap = new HashMap<>();
    public PoolManager(Main main){
        plugin = main;
        FileConfiguration yml = plugin.getConfig();
        ConfigurationSection section = yml.getConfigurationSection("PoolData");
        if(section != null) {
            for (String uuid : section.getKeys(false)){
                Map<String,Integer> integerMap = new HashMap<>();
                ConfigurationSection section1 = section.getConfigurationSection(uuid);
                for (String poolKey : section1.getKeys(false)){
                    integerMap.put(poolKey,section1.getInt(poolKey));
                }
                UUID uuid1 = UUID.fromString(uuid);
                uuidDataMap.put(uuid1,integerMap);
            }
            DemonAPI.sendConsoleMessage("§f[§a!§f] §f玩家数据 §8> §6"+uuidDataMap.size()+" 条");
        }
        File folder = new File("./plugins","CrazyPrizePool");
        File[] files = folder.listFiles((dir, name) -> name.endsWith(".yml")); // 列出目录下所有以 .yml 结尾的文件
        if (files != null) { // 确保目录存在且不是空的
            for (File file : files) { // 遍历每个文件
                String fileName = file.getName().replace(".yml","");
                if(!fileName.contains("config")) {
                    poolDataMap.put(fileName,new PoolData(plugin,fileName));
                }
            }
            DemonAPI.sendConsoleMessage("§f[§a!§f] §f奖池方案 §8> §6"+poolDataMap.size()+" 个");
        }
    }

    public void SavePlayerData(){
        FileConfiguration yml = plugin.getConfig();
        for (UUID uuid : uuidDataMap.keySet()){
            Map<String,Integer> integerMap = uuidDataMap.get(uuid);
            for (String poolKey : integerMap.keySet()) {
                yml.set("PoolData." + uuid+"."+poolKey,integerMap.get(poolKey));
            }
        }
        plugin.saveConfig();
    }

    // 根据手持物品判断奖池
    public PoolData getItemConvertPoolData(ItemStack stack){
        if(DemonAPI.itemIsNull(stack) || DemonAPI.itemIsLore(stack)){
            return null;
        }
        ItemMeta stackMeta = stack.getItemMeta();
        for (String poolKey : poolDataMap.keySet()){
            PoolData poolData = poolDataMap.get(poolKey);
            ItemStack poolItem = poolData.getItem();
            if(DemonAPI.itemIsNull(poolItem) || DemonAPI.itemIsLore(poolItem)){
                continue;
            }
            ItemMeta meta = poolItem.getItemMeta();
            if(meta.getDisplayName().contains(stackMeta.getDisplayName())){
                if(meta.getLore().get(1).equalsIgnoreCase(stackMeta.getLore().get(1))){
                    return poolData;
                }
            }
        }
        return null;
    }
    // 根据Key获取奖池
    public PoolData getPoolData(String poolKey){
        if(this.poolDataMap.get(poolKey) == null){
            return null;
        }
        return this.poolDataMap.get(poolKey);
    }
    // 获取玩家打开这个奖池累积次数
    public int getPlayerPoolAmount(UUID uuid,String poolKey){
        if(this.uuidDataMap.get(uuid) == null){
            return 0;
        }
        if(this.uuidDataMap.get(uuid).get(poolKey) == null){
            return 0;
        }
        return this.uuidDataMap.get(uuid).get(poolKey);
    }

    // 增加玩家打开这个奖池的累积次数
    public void addPlayerPoolAmount(UUID uuid,String poolKey,int amount){
        int nowAmount = getPlayerPoolAmount(uuid,poolKey);
        int newAmount = nowAmount + amount;
        setPlayerPoolAmount(uuid,poolKey,newAmount);
    }

    // 设置玩家打开这个奖池的累积次数
    public void setPlayerPoolAmount(UUID uuid,String poolKey,int amount){
        Map<UUID, Map<String,Integer>> uuidData = new HashMap<>();
        if(this.uuidDataMap.get(uuid) != null){
            uuidData = this.uuidDataMap;
        }
        if(uuidData.get(uuid).get(poolKey) == null){
            Map<String,Integer> integerMap = new HashMap<>();
            integerMap.put(poolKey,amount);
            uuidData.put(uuid,integerMap);
        }
        this.uuidDataMap = uuidData;
    }
}
